# [1.7.6](https://github.com/thesadru/genshin.py/compare/v1.7.5..v1.7.6) - 2025-02-28

## Continuous Integrations

- Clean up biweekly-release workflow - ([fd7622e](https://github.com/thesadru/genshin.py/commit/fd7622e27c4bd9b99079a3035bcc39c181992d22))

